% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_spatial.R
\docType{data}
\name{eurostat_geodata_60_2016}
\alias{eurostat_geodata_60_2016}
\title{Geospatial data of Europe from GISCO in 1:60 million scale from
year 2016}
\format{
sf object
}
\source{
Data source: Eurostat via \code{\link[giscoR:gisco_get_nuts]{giscoR::gisco_get_nuts()}}.

© EuroGeographics for the administrative boundaries

Data downloaded from:
\url{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/administrative-units-statistical-units}
}
\description{
Geospatial data of Europe from GISCO in 1:60 million scale
from year 2016
}
\details{
The dataset contains 2016 observations (rows) and 12 variables (columns).

The object contains the following columns:
\itemize{
\item \strong{id}: JSON id code, the same as \strong{NUTS_ID}. See \strong{NUTS_ID} below for
further clarification.
\item \strong{LEVL_CODE}: NUTS level code: 0 (national level), 1 (major
socio-economic regions), 2 (basic regions for the application of regional
policies) or 3 (small regions).
\item \strong{NUTS_ID}: NUTS ID code, consisting of country code and numbers (1 for
NUTS 1, 2 for NUTS 2 and 3 for NUTS 3)
\item \strong{CNTR_CODE}: Country code: two-letter ISO code (ISO 3166 alpha-2), except
in the case of Greece (EL).
\item \strong{NAME_LATN}: NUTS name in local language, transliterated to Latin script
\item \strong{NUTS_NAME}: NUTS name in local language, in local script.
\item \strong{MOUNT_TYPE}: Mountain typology for NUTS 3 regions.
\itemize{
\item 1: "where more than 50 \% of the surface is covered by topographic
mountain areas"
\item 2: "in which more than 50 \% of the regional population lives in
topographic mountain areas"
\item 3: "where more than 50 \% of the surface is covered by topographic
mountain areas and where more than 50 \% of the regional population lives
in these mountain areas"
\item 4: non-mountain region / other region
\item 0: no classification provided (e.g. in the case of NUTS 1 and NUTS 2 and
non-EU countries)
}
\item \strong{URBN_TYPE}: Urban-rural typology for NUTS 3 regions.
\itemize{
\item 1: predominantly urban region
\item 2: intermediate region
\item 3: predominantly rural region
\item 0: no classification provided (e.g. in the case of NUTS 1 and NUTS 2
regions)
}
\item \strong{COAST_TYPE}: Coastal typology for NUTS 3 regions.
\itemize{
\item 1: coastal (on coast)
\item 2: coastal (>= 50\% of population living within 50km of the coastline)
\item 3: non-coastal region
\item 0: no classification provided (e.g. in the case of NUTS 1 and NUTS 2
regions)
}
\item \strong{FID}: Same as NUTS_ID.
\item \strong{geo}: Same as NUTS_ID, added for for easier joins with dplyr. However,
it is recommended to use other identical fields for this purpose.
\item \strong{geometry}: geospatial information.
}

Dataset updated: 2023-06-29. For a more recent version, please use
\code{\link[giscoR:gisco_get_nuts]{giscoR::gisco_get_nuts()}} function.
}
\examples{

eurostat_geodata_60_2016 <- eurostat::eurostat_geodata_60_2016

# Manipulate and plot
if (require(sf)) {
  library(sf)
  # Filter NUTS3 from select countries like in a regular data frame
  example_nuts <- subset(eurostat_geodata_60_2016, LEVL_CODE == 3 &
    CNTR_CODE \%in\% c("DK", "DE", "PL"))

  plot(example_nuts["CNTR_CODE"])
}

}
\references{
The following copyright notice is provided for end user convenience.
Please check up-to-date copyright information from the eurostat website:
\href{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/administrative-units-statistical-units}{GISCO: Geographical information and maps - Administrative units/statistical units}

"In addition to the
\href{https://ec.europa.eu/eurostat/web/main/about/policies/copyright}{general copyright and licence policy}
applicable to the whole Eurostat website, the following
specific provisions apply to the datasets you are downloading. The download
and usage of these data is subject to the acceptance of the following
clauses:
\enumerate{
\item The Commission agrees to grant the non-exclusive and not transferable
right to use and process the Eurostat/GISCO geographical data downloaded
from this page (the "data").
\item The permission to use the data is granted on condition that:
\enumerate{
\item the data will not be used for commercial purposes;
\item the source will be acknowledged. A copyright notice, as specified
below, will have to be visible on any printed or electronic publication
using the data downloaded from this page.
}
}
\subsection{Copyright notice}{

When data downloaded from this page is used in any printed or electronic
publication, in addition to any other provisions applicable to the whole
Eurostat website, data source will have to be acknowledged in the legend of
the map and in the introductory page of the publication with the following
copyright notice:

EN: © EuroGeographics for the administrative boundaries

FR: © EuroGeographics pour les limites administratives

DE: © EuroGeographics bezüglich der Verwaltungsgrenzen

For publications in languages other than English, French or German, the
translation of the copyright notice in the language of the publication shall
be used.

If you intend to use the data commercially, please contact EuroGeographics
for information regarding their licence agreements."
}
}
\seealso{
\code{\link[giscoR:gisco_get_nuts]{giscoR::gisco_get_nuts()}} and
\href{https://ec.europa.eu/eurostat/web/products-manuals-and-guidelines/-/ks-gq-18-008}{Eurostat. (2019). Methodological manual on territorial typologies -- 2018 edition. Manuals and guidelines.}

Other datasets: 
\code{\link{eu_countries}},
\code{\link{tgs00026}}

Other geospatial: 
\code{\link{get_eurostat_geospatial}()}
}
\concept{datasets}
\concept{geospatial}
